Mapof
=====

This open-source, MIT-licensed package is a core part of the mapof ecosystem.
This framework allow for representing various features of (computational) problem instances
in the context of the instance structure in a visually appealing way.
Mapof is a direct successor of mapel, which will be deprecated in the (unforeseen) future.

Mapof Components
----------------
List of available packages within the mapof ecosystem:

- `Mapof-elections <https://science-for-democracy.github.io/mapof-elections>`_
- `Mapof-roommates <https://science-for-democracy.github.io/mapof-roommates>`_
- `Mapof-marriages <https://science-for-democracy.github.io/mapof-marriages>`_
- Mapof-tournaments (coming soon)
- Mapof-allocations (coming soon)


.. toctree::
    :hidden:

    Mapof <self>
    installation
    quickstart
    reference/index
    resources
    citation

